@@ -1,7 +1,7 @@
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 from .range import RangeParser, Range
-from .feature import Task
+from .task import Task
 from .distribution import (
     Distribution,
     Source,
